@@ -9,12 +9,14 @@ import os
 import re
 import string
 import sys
+import shutil
 import warnings
 from collections import namedtuple
 from itertools import islice
 from math import ceil
 from os.path import getmtime
 from threading import Lock
+from pkg_resources import get_distribution
 
 from six import PY2, PY3, integer_types, string_types
 from six.moves import zip_longest
@@ -23,15 +25,14 @@ try:
     from collections import OrderedDict
 except ImportError:  #python 2.6
     from ordereddict import OrderedDict
+    
+__version__ = get_distribution("pyfaidx").version
 
 if sys.version_info > (3, ):
     buffer = memoryview
 
 dna_bases = re.compile(r'([ACTGNactgnYRWSKMDVHBXyrwskmdvhbx]+)')
 
-__version__ = '0.5.9.2'
-
-
 class KeyFunctionError(ValueError):
     """Raised if the key_function argument is invalid."""
 
@@ -44,6 +45,10 @@ class IndexNotFoundError(IOError):
     """Raised if read_fai cannot open the index file."""
 
 
+class VcfIndexNotFoundError(IOError):
+    """Raised if vcf cannot find a tbi file."""
+
+
 class FastaNotFoundError(IOError):
     """Raised if the fasta file cannot be opened."""
 
@@ -347,8 +352,8 @@ class Faidx(object):
             try:
                 from Bio import bgzf
                 from Bio import __version__ as bgzf_version
-                from distutils.version import LooseVersion
-                if LooseVersion(bgzf_version) < LooseVersion('1.73'):
+                from packaging.version import Version
+                if Version(bgzf_version) < Version('1.73'):
                     raise ImportError
             except ImportError:
                 raise ImportError(
@@ -437,8 +442,8 @@ class Faidx(object):
                     self.read_fai()
 
             except FastaIndexingError:
-                os.remove(self.indexname)
                 self.file.close()
+                os.remove(self.indexname + '.tmp')
                 raise
             except Exception:
                 # Handle potential exceptions other than 'FastaIndexingError'
@@ -515,7 +520,7 @@ class Faidx(object):
     def build_index(self):
         try:
             with self._fasta_opener(self.filename, 'rb') as fastafile:
-                with open(self.indexname, 'w') as indexfile:
+                with open(self.indexname + '.tmp', 'w') as indexfile:
                     rname = None  # reference sequence name
                     offset = 0  # binary offset of end of current line
                     rlen = 0  # reference character length
@@ -596,6 +601,7 @@ class Faidx(object):
                                 "Inconsistent line found in >{0} at "
                                 "line {1:n}.".format(rname,
                                                      bad_lines[0][0] + 1))
+            shutil.move(self.indexname + '.tmp', self.indexname)
         except (IOError, FastaIndexingError) as e:
             if isinstance(e, IOError):
                 raise IOError(
@@ -1128,6 +1134,8 @@ class FastaVariant(Fasta):
             self.vcf = vcf.Reader(filename=vcf_file)
         else:
             raise IOError("File {0} does not exist.".format(vcf_file))
+        if not os.path.exists(vcf_file + '.tbi'):
+            raise VcfIndexNotFoundError("File {0} has not tabix index.".format(vcf_file))
         if sample is not None:
             self.sample = sample
         else:
@@ -1161,14 +1169,24 @@ class FastaVariant(Fasta):
         else:
             seq_mut = list(seq.seq)
             del seq.seq
-        var = self.vcf.fetch(name, start - 1, end)
-        for record in var:
-            if record.is_snp:  # skip indels
-                sample = record.genotype(self.sample)
-                if sample.gt_type in self.gt_type and eval(self.filter):
-                    alt = record.ALT[0]
-                    i = (record.POS - 1) - (start - 1)
-                    seq_mut[i:i + len(alt)] = str(alt)
+        try:
+            var = self.vcf.fetch(name, start - 1, end)
+            for record in var:
+                if record.is_snp:  # skip indels
+                    sample = record.genotype(self.sample)
+                    if sample.gt_type in self.gt_type and eval(self.filter):
+                        alt = record.ALT[0]
+                        i = (record.POS - 1) - (start - 1)
+                        seq_mut[i:i + len(alt)] = str(alt)
+        except ValueError as e: # Can be raised if name is not part of tabix for vcf
+            if self.vcf._tabix is not None and name not in self.vcf._tabix.contigs:
+                # The chromosome name is not part of the vcf
+                # The sequence returned is the same as the reference
+                pass
+            else:
+                # This is something else
+                raise e
+
         # slice the list in case we added an MNP in last position
         if self.faidx.as_raw:
             return ''.join(seq_mut[:end - start + 1])
